# fallback_toolkit

[![PyPI - Version](https://img.shields.io/pypi/v/fallback-toolkit.svg)](https://pypi.org/project/fallback-toolkit)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fallback-toolkit.svg)](https://pypi.org/project/fallback-toolkit)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
-----

(Yet Another) fallback implementation for python.


*No dependencies outside of standard python libraries*


## Table of Contents

- [Installation](#installation)
- [Examples](#examples)
- [License](#license)

## Installation

```console
pip install fallback-toolkit
```


## License

`fallback-toolkit` is distributed under the terms of the
[MIT](https://spdx.org/licenses/MIT.html) license.

